@@ -4,6 +4,7 @@
 # Original python was by A. Greenbaum & A. Sivaramakrishnan
 
 import os
+import logging
 
 import numpy as np
 from scipy.special import comb
@@ -13,6 +14,9 @@ from .. import datamodels
 from . import lg_model
 from . import utils
 
+log = logging.getLogger(__name__)
+log.setLevel(logging.DEBUG)
+
 
 class FringeFitter:
     def __init__(self, instrument_data, **kwargs):
