@@ -1,7 +1,7 @@
 from .assign_wcs_step import AssignWcsStep
 from .nirspec import (nrs_wcs_set_input, nrs_ifu_wcs, get_spectral_order_wrange)
 from .niriss import niriss_soss_set_input
-
+from .util import update_fits_wcsinfo
 
 __all__ = ['AssignWcsStep', "nrs_wcs_set_input", "nrs_ifu_wcs", "get_spectral_order_wrange",
-           "niriss_soss_set_input"]
+           "niriss_soss_set_input", "update_fits_wcsinfo"]
