@@ -126,9 +126,9 @@ def imaging_distortion(input_model, reference_files):
     # Check if the transform in the reference file has a ``bounding_box``.
     # If not set a ``bounding_box`` equal to the size of the image.
     try:
-        distortion.bounding_box
+        bbox = distortion.bounding_box
     except NotImplementedError:
-        distortion.bounding_box = transform_bbox_from_shape(input_model.data.shape)
+        bbox = distortion.bounding_box = None
 
     # Add an offset for the filter
     obsfilter = input_model.meta.instrument.filter
@@ -143,9 +143,12 @@ def imaging_distortion(input_model, reference_files):
             row_offset = f.row_offset
             break
 
-    if (col_offset is not None) and (row_offset is not None):
+    if col_offset is not None and row_offset is not None:
         distortion = models.Shift(col_offset) & models.Shift(row_offset) | distortion
-
+    if bbox is None:
+        distortion.bounding_box = transform_bbox_from_shape(input_model.data.shape)
+    else:
+        distortion.bounding_box = bbox
     return distortion
 
 
