@@ -120,11 +120,12 @@ def imaging_distortion(input_model, reference_files):
     transform = dist.model
 
     try:
-        transform.bounding_box
+        bbox = transform.bounding_box
     except NotImplementedError:
         # Check if the transform in the reference file has a ``bounding_box``.
-        # If not set a ``bounding_box`` equal to the size of the image.
-        transform.bounding_box = transform_bbox_from_shape(input_model.data.shape)
+        # If not set a ``bounding_box`` equal to the size of the image after
+        # assembling all distortion corrections.
+        bbox = None
     dist.close()
 
     # Add an offset for the filter
@@ -137,12 +138,17 @@ def imaging_distortion(input_model, reference_files):
         match_keys = {'filter': obsfilter, 'pupil': obspupil}
         row = find_row(filters, match_keys)
         if row is not None:
-            col_offset = row.get('col_offset', 'N/A')
+            col_offset = row.get('column_offset', 'N/A')
             row_offset = row.get('row_offset', 'N/A')
-
+            log.debug(f"Offsets from filteroffset file are {col_offset}, {row_offset}")
             if col_offset != 'N/A' and row_offset != 'N/A':
                 transform = Shift(col_offset) & Shift(row_offset) | transform
-
+        else:
+            log.debug("No match in fitleroffset file.")
+    if bbox is None:
+        transform.bounding_box = transform_bbox_from_shape(input_model.data.shape)
+    else:
+        transform.bounding_box = bbox
     return transform
 
 
