@@ -95,11 +95,11 @@ def _niriss_order_bounding_box(input_model, order):
     bbox_x = np.array([-0.5, input_model.meta.subarray.xsize - 0.5])
 
     if order == 1:
-        return (tuple(bbox_y), tuple(bbox_x))
+        return tuple(bbox_y), tuple(bbox_x)
     elif order == 2:
-        return (tuple(bbox_y), tuple(bbox_x))
+        return tuple(bbox_y), tuple(bbox_x)
     elif order == 3:
-        return (tuple(bbox_y), tuple(bbox_x))
+        return tuple(bbox_y), tuple(bbox_x)
     else:
         raise ValueError(f'Invalid spectral order: {order} provided. Spectral order must be 1, 2, or 3.')
 
@@ -287,11 +287,12 @@ def imaging_distortion(input_model, reference_files):
     distortion = dist.model
 
     try:
-        # Check if the model has a bounding box.
-        distortion.bounding_box
+        bbox = distortion.bounding_box
     except NotImplementedError:
-        distortion.bounding_box = transform_bbox_from_shape(input_model.data.shape)
-
+        # Check if the transform in the reference file has a ``bounding_box``.
+        # If not set a ``bounding_box`` equal to the size of the image after
+        # assembling all distortion corrections.
+        bbox = None
     dist.close()
 
     # Add an offset for the filter
@@ -304,11 +305,18 @@ def imaging_distortion(input_model, reference_files):
         match_keys = {'filter': obsfilter, 'pupil': obspupil}
         row = find_row(filters, match_keys)
         if row is not None:
-            col_offset = row.get('col_offset', 'N/A')
+            col_offset = row.get('column_offset', 'N/A')
             row_offset = row.get('row_offset', 'N/A')
+            log.info(f"Offsets from filteroffset file are {col_offset}, {row_offset}")
 
             if col_offset != 'N/A' and row_offset != 'N/A':
                 distortion = Shift(col_offset) & Shift(row_offset) | distortion
+        else:
+            log.debug("No match in fitleroffset file.")
+    if bbox is None:
+        distortion.bounding_box = transform_bbox_from_shape(input_model.data.shape)
+    else:
+        distortion.bounding_box = bbox
     return distortion
 
 
@@ -333,7 +341,7 @@ def wfss(input_model, reference_files):
     -----
     reference_files = {
         "specwcs": 'GR150C_F090W.asdf'
-        "distortion": 'NRCA1_FULL_distortion.asdf'
+        "distortion": 'NIRISS_FULL_distortion.asdf'
         }
 
     The tree in the grism reference file has a section for each order/beam as
@@ -416,13 +424,13 @@ def wfss(input_model, reference_files):
                                                   lmodels=displ,
                                                   xmodels=dispx,
                                                   ymodels=dispy,
-                                                  theta=fwcpos_ref - fwcpos)
+                                                  theta=fwcpos - fwcpos_ref)
     elif input_model.meta.instrument.filter.endswith('R'):
         det2det = NIRISSForwardColumnGrismDispersion(orders,
                                                      lmodels=displ,
                                                      xmodels=dispx,
                                                      ymodels=dispy,
-                                                     theta=fwcpos_ref - fwcpos)
+                                                     theta=fwcpos - fwcpos_ref)
     else:
         raise ValueError("FILTER keyword {} is not valid."
                          .format(input_model.meta.instrument.filter))
@@ -431,7 +439,7 @@ def wfss(input_model, reference_files):
                                              lmodels=invdispl,
                                              xmodels=dispx,
                                              ymodels=dispy,
-                                             theta=fwcpos_ref - fwcpos)
+                                             theta=-(fwcpos - fwcpos_ref))
     det2det.inverse = backward
 
     # Add in the wavelength shift from the velocity dispersion
