@@ -15,6 +15,8 @@ class Combine1dStep(Step):
 
     """
 
+    class_alias = "combine_1d"
+
     spec = """
     exptime_key = string(default="exposure_time") # use for weight
     """
@@ -24,6 +26,5 @@ class Combine1dStep(Step):
         with datamodels.open(input_file) as input_model:
             result = combine1d.combine_1d_spectra(input_model,
                                                   self.exptime_key)
-        result.meta.filetype = '1d combined spectrum'
 
         return result
