@@ -65,7 +65,7 @@ def read_cubepars(par_filename,
                     table_wavemin = tabdata['WAVEMIN']
                     table_wavemax = tabdata['WAVEMAX']
                     # match on this_channel and this_sub
-                    if(this_channel == table_channel and this_sub == table_band):
+                    if this_channel == table_channel and this_sub == table_band:
                         instrument_info.SetSpatialSize(table_spaxelsize, this_channel, this_sub)
                         instrument_info.SetSpectralStep(table_spectralstep, this_channel, this_sub)
                         instrument_info.SetWaveMin(table_wavemin, this_channel, this_sub)
@@ -80,7 +80,7 @@ def read_cubepars(par_filename,
                         table_power = tabdata['POWER']
                         table_softrad = tabdata['SOFTRAD']
                     # match on this_channel and this_sub
-                        if(this_channel == table_channel and this_sub == table_band):
+                        if this_channel == table_channel and this_sub == table_band:
                             instrument_info.SetMSM(this_channel, this_sub,
                                                    table_sroi, table_wroi,
                                                    table_power, table_softrad)
@@ -94,7 +94,7 @@ def read_cubepars(par_filename,
                         table_wroi = tabdata['ROISPECTRAL']
                         table_scalerad = tabdata['SCALERAD']
                     # match on this_channel and this_sub
-                        if(this_channel == table_channel and this_sub == table_band):
+                        if this_channel == table_channel and this_sub == table_band:
                             instrument_info.SetEMSM(this_channel, this_sub,
                                                     table_sroi, table_wroi,
                                                     table_scalerad)
@@ -140,7 +140,7 @@ def read_cubepars(par_filename,
                     table_wavemin = tabdata['WAVEMIN']
                     table_wavemax = tabdata['WAVEMAX']
 
-                    if(this_gwa == table_grating and this_filter == table_filter):
+                    if this_gwa == table_grating and this_filter == table_filter:
                         instrument_info.SetSpatialSize(table_spaxelsize, this_gwa, this_filter)
                         instrument_info.SetSpectralStep(table_spectralstep, this_gwa, this_filter)
                         instrument_info.SetWaveMin(table_wavemin, this_gwa, this_filter)
@@ -156,7 +156,7 @@ def read_cubepars(par_filename,
                         table_power = tabdata['POWER']
                         table_softrad = tabdata['SOFTRAD']
 
-                        if(this_gwa == table_grating and this_filter == table_filter):
+                        if this_gwa == table_grating and this_filter == table_filter:
                             instrument_info.SetMSM(this_gwa, this_filter,
                                                    table_sroi, table_wroi,
                                                    table_power, table_softrad)
@@ -169,7 +169,7 @@ def read_cubepars(par_filename,
                         table_wroi = tabdata['ROISPECTRAL']
                         table_scalerad = tabdata['SCALERAD']
 
-                        if(this_gwa == table_grating and this_filter == table_filter):
+                        if this_gwa == table_grating and this_filter == table_filter:
                             instrument_info.SetEMSM(this_gwa, this_filter,
                                                     table_sroi, table_wroi,
                                                     table_scalerad)
