@@ -124,8 +124,8 @@ def test_call_cube_build(_jail, miri_cube_pars, miri_image):
         pass
 
     assert step.pars_input['channel'] == ['1']
-    assert step.interpolation == 'pointcloud'
-    assert step.weighting == 'emsm'
+    assert step.interpolation == 'drizzle'
+    assert step.weighting == 'drizzle'
     assert step.coord_system == 'skyalign'
 
     # Set Assign WCS has been run but the user input to channels is wrong
