@@ -20,7 +20,7 @@ class Extract1dStep(Step):
         A string indicating the type of fitting to be applied to
         background values in each column (or row, if the dispersion is
         vertical). Allowed values are `poly`, `mean`, and `median`.
-        Default is `poly`.
+        Default is `None`.
 
     bkg_order : int or None
         If not None, a polynomial with order `bkg_order` will be fit to
@@ -103,9 +103,11 @@ class Extract1dStep(Step):
         Filename for optional model output of ATOCA traces and pixel weights.
     """
 
+    class_alias = "extract_1d"
+
     spec = """
     smoothing_length = integer(default=None)  # background smoothing size
-    bkg_fit = option("poly", "mean", "median", default="poly")  # background fitting type
+    bkg_fit = option("poly", "mean", "median", None, default=None)  # background fitting type
     bkg_order = integer(default=None, min=0)  # order of background polynomial fit
     bkg_sigma_clip = float(default=3.0)  # background sigma clipping threshold
     log_increment = integer(default=50)  # increment for multi-integration log messages
@@ -113,7 +115,6 @@ class Extract1dStep(Step):
     use_source_posn = boolean(default=None)  # use source coords to center extractions?
     center_xy = int_list(min=2, max=2, default=None)  # IFU extraction x/y center
     apply_apcorr = boolean(default=True)  # apply aperture corrections?
-    soss_atoca = boolean(default=False)  # use ATOCA algorithm - should have photom off and not fully tested
     soss_threshold = float(default=1e-2)  # threshold value for a pixel to be included when modelling the trace.
     soss_n_os = integer(default=2)  # oversampling factor of the underlying wavelength grid used when modeling trace.
     soss_transform = float_list(default=None, min=3, max=3)  # rotation applied to the ref files to match observation.
@@ -217,9 +218,8 @@ class Extract1dStep(Step):
                     # Set the step flag to complete
                     result.meta.cal_step.extract_1d = 'COMPLETE'
 
-                    # --------------------------------------------------------------
-                    # Data is a ModelContainer but is not WFSS
-                    result.meta.filetype = '1d spectrum'
+                # --------------------------------------------------------------
+                # Data is a ModelContainer but is not WFSS
                 else:
                     result = datamodels.ModelContainer()
                     for model in input_model:
@@ -251,7 +251,6 @@ class Extract1dStep(Step):
                         )
                         # Set the step flag to complete in each MultiSpecModel
                         temp.meta.cal_step.extract_1d = 'COMPLETE'
-                        temp.meta.filetype = '1d spectrum'
                         result.append(temp)
                         del temp
             # ------------------------------------------------------------------------
@@ -290,7 +289,6 @@ class Extract1dStep(Step):
 
                 # Set the step flag to complete
                 result.meta.cal_step.extract_1d = 'COMPLETE'
-                result.meta.filetype = '1d spectrum'
             else:
                 self.log.error('Input model is empty;')
                 self.log.error('extract_1d will be skipped.')
@@ -300,7 +298,7 @@ class Extract1dStep(Step):
         # Data that is not a ModelContainer (IFUCube and other single models)
         else:
             # Data is NRISS SOSS observation.
-            if input_model.meta.exposure.type == 'NIS_SOSS' and self.soss_atoca:
+            if input_model.meta.exposure.type == 'NIS_SOSS':
 
                 self.log.info(
                     'Input is a NIRISS SOSS observation, the specialized SOSS extraction (ATOCA) will be used.')
@@ -366,18 +364,20 @@ class Extract1dStep(Step):
                     soss_kwargs)
 
                 # Set the step flag to complete
-                result.meta.cal_step.extract_1d = 'COMPLETE'
-                result.meta.filetype = '1d spectrum'
-                result.meta.target.source_type = None
+                if result is None:
+                    return None
+                else:
+                    result.meta.cal_step.extract_1d = 'COMPLETE'
+                    result.meta.target.source_type = None
 
-                input_model.close()
+                    input_model.close()
 
-                if self.soss_modelname:
-                    soss_modelname = self.make_output_path(
-                        basepath=self.soss_modelname,
-                        suffix='SossExtractModel'
-                    )
-                    ref_outputs.save(soss_modelname)
+                    if self.soss_modelname:
+                        soss_modelname = self.make_output_path(
+                            basepath=self.soss_modelname,
+                            suffix='SossExtractModel'
+                        )
+                        ref_outputs.save(soss_modelname)
 
             else:
                 # Get the reference file names
@@ -413,7 +413,6 @@ class Extract1dStep(Step):
 
                 # Set the step flag to complete
                 result.meta.cal_step.extract_1d = 'COMPLETE'
-                result.meta.filetype = '1d spectrum'
 
         input_model.close()
 
