@@ -3,8 +3,10 @@ import logging
 import numpy as np
 from scipy.interpolate import UnivariateSpline
 
+from ..extract import populate_time_keywords
+from ...lib import pipe_utils
 from ... import datamodels
-from ...datamodels.dqflags import pixel
+from ...datamodels import dqflags
 from astropy.nddata.bitmask import bitfield_to_boolean_mask
 
 from .soss_syscor import make_background_mask, soss_background
@@ -295,11 +297,15 @@ def model_image(scidata_bkg, scierr, scimask, refmask, ref_file_args, transform=
         log.info('Solving for the optimal Tikhonov factor.')
 
         # Need a rough estimate of the underlying flux to estimate the tikhonov factor
-        estimate = estim_flux_first_order(scidata_bkg, scierr, scimask, ref_file_args, threshold)
-
+        try:
+            estimate = estim_flux_first_order(scidata_bkg, scierr, scimask, ref_file_args, threshold)
+            # Initial pass 8 orders of magnitude with 10 grid points.
+            factors = engine.estimate_tikho_factors(estimate, log_range=[-4, 4], n_points=10)
+        except Exception as e:
+            log.warning(f"Error caught in first order flux estimation: {e}\n"
+                        f"Using pre-defined array for flux factor estimate.")
+            factors = np.logspace(-19, -10, 10)
         # Find the tikhonov factor.
-        # Initial pass 8 orders of magnitude with 10 grid points.
-        factors = engine.estimate_tikho_factors(estimate, log_range=[-4, 4], n_points=10)
         tiktests = engine.get_tikho_tests(factors, data=scidata_bkg, error=scierr, mask=scimask)
         tikfac, mode, _ = engine.best_tikho_factor(tests=tiktests, fit_mode='chi2')
 
@@ -536,7 +542,9 @@ def run_extract1d(input_model, spectrace_ref_name, wavemap_ref_name,
         scidata = input_model.data.astype('float64')
         scierr = input_model.err.astype('float64')
         scimask = input_model.dq > 0  # Mask bad pixels with True.
-        refmask = bitfield_to_boolean_mask(input_model.dq, ignore_flags=pixel['REFERENCE_PIXEL'], flip_bits=True)
+        refmask = bitfield_to_boolean_mask(input_model.dq,
+                                           ignore_flags=dqflags.pixel['REFERENCE_PIXEL'],
+                                           flip_bits=True)
 
         # Perform background correction.
         bkg_mask = make_background_mask(scidata, width=40)
@@ -568,7 +576,8 @@ def run_extract1d(input_model, spectrace_ref_name, wavemap_ref_name,
         ref_file_args = get_ref_file_args(ref_files, transform)
 
         # Make sure wavelength maps cover only parts where the centroid is inside the detector image
-        _mask_wv_map_centroid_outside(ref_file_args[0], ref_files, transform, scidata_bkg.shape[0])
+        if subarray != 'SUBSTRIP96':
+            _mask_wv_map_centroid_outside(ref_file_args[0], ref_files, transform, scidata_bkg.shape[0])
 
         # Model the traces based on optics filter configuration (CLEAR or F277W)
         if soss_filter == 'CLEAR':
@@ -587,7 +596,7 @@ def run_extract1d(input_model, spectrace_ref_name, wavemap_ref_name,
             # No model can be fit for F277W yet, missing throughput reference files.
             msg = f"No extraction possible for filter {soss_filter}."
             log.critical(msg)
-            raise ValueError(msg)
+            return None, None
 
         # Save trace models for output reference
         for order in tracemodels:
@@ -652,8 +661,9 @@ def run_extract1d(input_model, spectrace_ref_name, wavemap_ref_name,
             # Unpack the i-th image, set dtype to float64 and convert DQ to boolean mask.
             scidata = input_model.data[i].astype('float64')
             scierr = input_model.err[i].astype('float64')
-            scimask = input_model.dq[i] > 0
-            refmask = bitfield_to_boolean_mask(input_model.dq[i], ignore_flags=pixel['REFERENCE_PIXEL'], flip_bits=True)
+            scimask = np.bitwise_and(input_model.dq[i], dqflags.pixel['DO_NOT_USE']).astype(bool)
+            refmask = bitfield_to_boolean_mask(input_model.dq[i], ignore_flags=dqflags.pixel['REFERENCE_PIXEL'],
+                                               flip_bits=True)
 
             # Perform background correction.
             bkg_mask = make_background_mask(scidata, width=40)
@@ -704,7 +714,7 @@ def run_extract1d(input_model, spectrace_ref_name, wavemap_ref_name,
                 # No model can be fit for F277W yet, missing throughput reference files.
                 msg = f"No extraction possible for filter {soss_filter}."
                 log.critical(msg)
-                raise ValueError(msg)
+                return None, None
 
             # Save trace models for output reference
             for order in tracemodels:
@@ -760,7 +770,7 @@ def run_extract1d(input_model, spectrace_ref_name, wavemap_ref_name,
     else:
         msg = "Only ImageModel and CubeModel are implemented for the NIRISS SOSS extraction."
         log.critical(msg)
-        raise ValueError(msg)
+        return None, None
 
     # Save output references
     for order in all_tracemodels:
@@ -777,4 +787,9 @@ def run_extract1d(input_model, spectrace_ref_name, wavemap_ref_name,
         order_int = order_str_2_int[order]
         setattr(output_references, f'aperture{order_int}', box_w_ord)
 
+    if pipe_utils.is_tso(input_model):
+        log.info("Populating INT_TIMES keywords from input table.")
+        populate_time_keywords(input_model, output_model)
+        output_model.int_times = input_model.int_times.copy()
+
     return output_model, output_references
