@@ -8,6 +8,8 @@ from jwst.jump.jump import run_detect_jumps
 from jwst.datamodels import dqflags
 import multiprocessing
 
+import time
+import random
 
 JUMP_DET = dqflags.group["JUMP_DET"]
 DO_NOT_USE = dqflags.group["DO_NOT_USE"]
@@ -16,12 +18,62 @@ SATURATED = dqflags.group["SATURATED"]
 NO_GAIN_VALUE = dqflags.pixel["NO_GAIN_VALUE"]
 
 
+def test_exec_time_0_crs(setup_inputs):
+    """"
+    Set up with dimension similar to simulated MIRI datasets, Dataset has no
+    cosmic rays. Test only the execution time of run_detect_jumps() for
+    comparison with nominal time; hopefully indicative of faults with newly
+    added code.
+    """
+    model, rnoise, gain = setup_inputs(ngroups=10, nrows=1024, ncols=1032,
+                                       nints=2, readnoise=6.5, gain=5.5,
+                                       grouptime=2.775, deltatime=2.775)
+
+    tstart = time.time()
+    # using dummy variable in next to prevent "F841-variable is assigned to but never used"
+    _ = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, True)
+    tstop = time.time()
+
+    t_elapsed = tstop - tstart
+    MAX_TIME = 10  # takes 1.6 sec on my Mac
+
+    assert t_elapsed < MAX_TIME
+
+
+def test_exec_time_many_crs(setup_inputs):
+    """"
+    Set up with dimension similar to simulated MIRI datasets, Dataset has
+    many cosmic rays; approximately one CR per 4 groups. Test only the execution
+    time of run_detect_jumps() for comparison with nominal time; hopefully
+    indicative of faults with newly added code.
+    """
+    nrows = 350
+    ncols = 400
+
+    model, rnoise, gain = setup_inputs(ngroups=10, nrows=nrows, ncols=ncols,
+                                       nints=2, readnoise=6.5, gain=5.5,
+                                       grouptime=2.775, deltatime=2.775)
+
+    crs_frac = 0.25  # fraction of groups having a CR
+    model = add_crs(model, crs_frac)  # add desired fraction of CRs
+
+    tstart = time.time()
+    # using dummy variable in next to prevent "F841-variable is assigned to but never used"
+    _ = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, True)
+    tstop = time.time()
+
+    t_elapsed = tstop - tstart
+    MAX_TIME = 600  # takes ~100 sec on my Mac
+
+    assert t_elapsed < MAX_TIME
+
+
 def test_nocrs_noflux(setup_inputs):
     """"
     All pixel values are zero. So slope should be zero
     """
     model, rnoise, gain = setup_inputs(ngroups=5)
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 4, True)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, True)
     assert np.max(out_model.groupdq) == GOOD
 
 
@@ -33,7 +85,7 @@ def test_nocrs_noflux_badgain_pixel(setup_inputs):
     model, rnoise, gain = setup_inputs(ngroups=5, nrows=20, ncols=20)
     gain.data[7, 7] = -10  # bad gain
     gain.data[17, 17] = np.nan  # bad gain
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 4, True)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, True)
 
     # 2 bits are set for each pixel, so use bitwise_and to check is set
     assert np.bitwise_and(out_model.pixeldq[7, 7], NO_GAIN_VALUE) == NO_GAIN_VALUE
@@ -48,7 +100,7 @@ def test_nocrs_noflux_subarray(setup_inputs):
     extracted from the full frame versions.
     """
     model, rnoise, gain = setup_inputs(ngroups=5, subarray=True)
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 4, True)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, True)
     assert np.max(out_model.groupdq) == GOOD
 
 
@@ -74,7 +126,7 @@ def test_onecr_10_groups_neighbors_flagged(setup_inputs):
     model.data[0, 7, 5, 5] = 160.0
     model.data[0, 8, 5, 5] = 170.0
     model.data[0, 9, 5, 5] = 180.0
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 4, True)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, True)
 
     assert np.max(out_model.groupdq[0, 5, 5, 5]) == JUMP_DET
     assert out_model.groupdq[0, 5, 5, 6] == JUMP_DET
@@ -109,7 +161,7 @@ def test_nocr_100_groups_nframes1(setup_inputs):
     model.data[0, 9, 5, 5] = 68.0
     for i in range(10, 100):
         model.data[0, i, 5, 5] = i * 5
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 4, True)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, True)
     assert np.max(out_model.groupdq) == GOOD
 
 
@@ -146,7 +198,7 @@ def test_twoints_onecr_each_10_groups_neighbors_flagged(setup_inputs):
     model.data[1, 7, 15, 5] = 160.0
     model.data[1, 8, 15, 5] = 170.0
     model.data[1, 9, 15, 5] = 180.0
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 4, True)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, True)
 
     assert np.max(out_model.groupdq[0, 5, 5, 5]) == JUMP_DET
     assert out_model.groupdq[0, 5, 5, 6] == JUMP_DET
@@ -224,7 +276,7 @@ def test_multiple_neighbor_jumps_firstlastbad(setup_inputs):
     # run jump detection
     out_model = run_detect_jumps(model, gain, rnoise, rejection_thresh=200.0, three_grp_thresh=200,
                                  four_grp_thresh=200,
-                                 max_cores=None, max_jump_to_flag_neighbors=200,
+                                 max_cores='none', max_jump_to_flag_neighbors=200,
                                  min_jump_to_flag_neighbors=10, flag_4_neighbors=True)
 
     # Verify that the correct groups have been flagged. The entries for pixels
@@ -282,7 +334,7 @@ def test_nirspec_saturated_pix(setup_inputs):
     # run jump detection
     out_model = run_detect_jumps(model, gain, rnoise, rejection_thresh=200.0, three_grp_thresh=200,
                                  four_grp_thresh=200,
-                                 max_cores=None, max_jump_to_flag_neighbors=200,
+                                 max_cores='none', max_jump_to_flag_neighbors=200,
                                  min_jump_to_flag_neighbors=10, flag_4_neighbors=True)
 
     # Check the results. There should not be any pixels with DQ values of 6, which
@@ -293,7 +345,35 @@ def test_nirspec_saturated_pix(setup_inputs):
     assert_array_equal(out_model.groupdq[0, :, 3, 3], [0, 4, 4, 0, 0, 4, 2])
 
 
-@pytest.mark.skip(reason='multiprocessing temporarily disabled')
+def add_crs(model, crs_frac):
+    """"
+    Randomly add a cosmic ray of magnitude CR_MAG to a fraction (crs_frac)
+    of the groups in the model's SCI array
+    """
+
+    num_ints = model.data.shape[0]
+    num_groups = model.data.shape[1]
+    num_rows = model.data.shape[2]
+    num_cols = model.data.shape[3]
+
+    tot_cr = 0  # counter
+    CR_MAG = 1000.  # consider making a variable ?
+
+    random.seed(0)  # to generate same CRs
+
+    # Add to the model's data, in all but the 0th group
+    for ii_int in range(num_ints):  # loop over integrations
+        for ii_col in range(num_cols):
+            for ii_row in range(num_rows):
+                for ii_group in range(1, num_groups):
+                    cr_rand = random.random()
+                    if cr_rand < crs_frac:
+                        tot_cr += 1
+                        model.data[ii_int, ii_group:, ii_row, ii_col] += CR_MAG
+
+    return model
+
+
 def test_flagging_of_CRs_across_slice_boundaries(setup_inputs):
     """"
     A multiprocessing test that has two CRs on the boundary between two slices.
@@ -335,7 +415,7 @@ def test_flagging_of_CRs_across_slice_boundaries(setup_inputs):
         model.data[1, 7, yincrement, 25] = 160.0
         model.data[1, 8, yincrement, 25] = 170.0
         model.data[1, 9, yincrement, 25] = 180.0
-        out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0,  max_cores, 200, 4, True)
+        out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, max_cores, 200, 4, True)
 
         # check that the neighbors of the CR on the last row were flagged
         assert out_model.groupdq[0, 5, yincrement - 1, 5] == JUMP_DET
@@ -351,7 +431,6 @@ def test_flagging_of_CRs_across_slice_boundaries(setup_inputs):
         assert out_model.groupdq[1, 7, yincrement - 1, 25] == JUMP_DET
 
 
-@pytest.mark.skip(reason='multiprocessing temporarily disabled')
 def test_twoints_onecr_10_groups_neighbors_flagged_multi(setup_inputs):
     """"
     A multiprocessing test that has two CRs on the boundary between two slices
@@ -387,7 +466,7 @@ def test_twoints_onecr_10_groups_neighbors_flagged_multi(setup_inputs):
     model.data[1, 7, 15, 5] = 160.0
     model.data[1, 8, 15, 5] = 170.0
     model.data[1, 9, 15, 5] = 180.0
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0,  'half', 200, 4, True)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'half', 200, 4, True)
 
     assert np.max(out_model.groupdq[0, 5, 5, 5]) == JUMP_DET
     assert out_model.groupdq[0, 5, 5, 6] == JUMP_DET
@@ -493,7 +572,7 @@ def test_crs_on_edge_with_neighbor_flagging(setup_inputs):
     model.data[0, 8, 15, -1] = 170.0
     model.data[0, 9, 15, -1] = 180.0
 
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 10, True)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 10, True)
 
     # flag CR and three neighbors of first row CR
     assert out_model.groupdq[0, 5, 0, 15] == JUMP_DET
@@ -540,7 +619,7 @@ def test_onecr_10_groups(setup_inputs):
     model.data[0, 7, 5, 5] = 160.0
     model.data[0, 8, 5, 5] = 170.0
     model.data[0, 9, 5, 5] = 180.0
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 10, False)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 10, False)
 
     assert out_model.groupdq[0, 5, 5, 5] == JUMP_DET
     assert out_model.groupdq[0, 5, 4, 5] == GOOD
@@ -579,7 +658,7 @@ def test_onecr_10_groups_fullarray(setup_inputs):
     model.data[0, 7, 5, 10] = 400
     model.data[0, 8, 5, 10] = 410
     model.data[0, 9, 5, 10] = 420
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 10, False)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 10, False)
 
     # The jump is in group 5 for columns 0-9
     assert_array_equal(out_model.groupdq[0, 5, 5, 0:10], JUMP_DET)
@@ -613,7 +692,7 @@ def test_onecr_50_groups(setup_inputs):
     model.data[0, 9, 5, 5] = 180.0
     model.data[0, 10:30, 5, 5] = np.arange(190, 290, 5)
     model.data[0, 30:50, 5, 5] = np.arange(500, 600, 5)
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 10, False)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 10, False)
 
     # CR in group 5
     assert out_model.groupdq[0, 5, 5, 5] == JUMP_DET
@@ -623,6 +702,47 @@ def test_onecr_50_groups(setup_inputs):
     assert_array_equal(out_model.groupdq[0, 6:30, 5, 5], GOOD)
 
 
+def test_onecr_50_groups_afterjump(setup_inputs):
+    """"
+    A test with a fifty group integration. There are two jumps in pixel 5,5. One in group 5 and
+    one in group 30.  Test includes after jump flagging.
+    """
+    grouptime = 3.0
+    ingain = 5
+    inreadnoise = 7.0
+    ngroups = 50
+    model, rnoise, gain = setup_inputs(ngroups=ngroups, gain=ingain, nrows=10, ncols=10,
+                                       readnoise=inreadnoise, deltatime=grouptime)
+
+    model.data[0, 0, 5, 5] = 15.0
+    model.data[0, 1, 5, 5] = 20.0
+    model.data[0, 2, 5, 5] = 25.0
+    model.data[0, 3, 5, 5] = 30.0
+    model.data[0, 4, 5, 5] = 35.0
+    model.data[0, 5, 5, 5] = 140.0
+    model.data[0, 6, 5, 5] = 150.0
+    model.data[0, 7, 5, 5] = 160.0
+    model.data[0, 8, 5, 5] = 170.0
+    model.data[0, 9, 5, 5] = 180.0
+    model.data[0, 10:30, 5, 5] = np.arange(190, 290, 5)
+    model.data[0, 30:50, 5, 5] = np.arange(500, 600, 5)
+    out_model = run_detect_jumps(model, gain, rnoise,
+                                 4.0, 5.0, 6.0, 'none', 200, 10, False,
+                                 after_jump_flag_dn1=20.,
+                                 after_jump_flag_time1=grouptime * 2,
+                                 after_jump_flag_dn2=150.,
+                                 after_jump_flag_time2=grouptime * 3)
+
+    # CR in group 5 + 2 groups
+    for k in range(5, 8):
+        assert out_model.groupdq[0, k, 5, 5] == JUMP_DET, f"first cr group {k}"
+    # CR in group 30 + 3 groups
+    for k in range(30, 34):
+        assert out_model.groupdq[0, k, 5, 5] == JUMP_DET, f"second cr group {k}"
+    # groups in between are not flagged
+    assert_array_equal(out_model.groupdq[0, 8:30, 5, 5], GOOD, err_msg="between crs")
+
+
 def test_single_CR_neighbor_flag(setup_inputs):
     """"
     A single CR in a 10 group exposure. Tests that:
@@ -651,7 +771,7 @@ def test_single_CR_neighbor_flag(setup_inputs):
     model.data[0, 9, 3, 3] = 180.0
 
     # Flag neighbors
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 4, True)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, True)
 
     assert np.max(out_model.groupdq[0, 5, 3, 3]) == JUMP_DET
     assert out_model.groupdq[0, 5, 3, 4] == JUMP_DET
@@ -660,7 +780,7 @@ def test_single_CR_neighbor_flag(setup_inputs):
     assert out_model.groupdq[0, 5, 4, 3] == JUMP_DET
 
     # Do not flag neighbors
-    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 1, 200, 4, False)
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, False)
 
     assert np.max(out_model.groupdq[0, 5, 3, 3]) == JUMP_DET
     assert out_model.groupdq[0, 5, 3, 4] == GOOD
@@ -669,7 +789,6 @@ def test_single_CR_neighbor_flag(setup_inputs):
     assert out_model.groupdq[0, 5, 4, 3] == GOOD
 
 
-@pytest.mark.skip(reason='multiprocessing temporarily disabled')
 def test_proc(setup_inputs):
     """"
     A single CR in a 10 group exposure. Verify that the pixels flagged using
@@ -696,7 +815,7 @@ def test_proc(setup_inputs):
     model.data[0, 8, 2, 3] = 170.0
     model.data[0, 9, 2, 3] = 180.0
 
-    out_model_a = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, None, 200, 4, True)
+    out_model_a = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, True)
     out_model_b = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'half', 200, 4, True)
     assert_array_equal(out_model_a.groupdq, out_model_b.groupdq)
 
@@ -781,6 +900,166 @@ def test_adjacent_CRs(setup_inputs):
 # Need test for multi-ints near zero with positive and negative slopes
 
 
+def test_cr_neighbor_sat_flagging(setup_inputs):
+    """"
+    For pixels impacted by cosmic rays, neighboring pixels that are not
+    already flagged as saturated will also be flagged as JUMP_DET. If a
+    neigboring pixel has been flagged as saturated, it should not also be
+    flagged as JUMP_DET.  This test checks if both of those types of
+    neighboring pixels are correctly flagged, and tests more cases than
+    covered by the tests test_nirspec_saturated_pix() and
+    test_crs_on_edge_with_neighbor_flagging().
+    """
+    SAT_SCI = 1E4  # dummy saturation level
+
+    grouptime = 3.0
+    ingain = 200
+    inreadnoise = 7.0
+    ngroups = 8
+    model, rnoise, gain = setup_inputs(ngroups=ngroups, gain=ingain, nrows=6,
+                                       ncols=7, readnoise=inreadnoise,
+                                       deltatime=grouptime)
+
+    # Construct ramps with cosmic rays having some neighboring SAT pixels:
+    # CR (A): group 2, in corner
+    model.data[0, 0, 0, 0] = 15.0
+    model.data[0, 1, 0, 0] = 20.0
+    model.data[0, 2, 0, 0] = 120.0
+    model.data[0, 3, 0, 0] = 125.0
+    model.data[0, 4, 0, 0] = 130.0
+    model.data[0, 5, 0, 0] = 135.0
+    model.data[0, 6, 0, 0] = 140.0
+    model.data[0, 7, 0, 0] = 145.0
+    # ... and set 1 of the 2 neighbors to SAT, and adjust its ramp
+    model.groupdq[0, 2:, 0, 1] = SATURATED
+    model.data[0, 2:, 0, 1] = SAT_SCI
+
+    # CR (B): group 2, not on edge
+    model.data[0, 0, 1, 4] = 30.0
+    model.data[0, 1, 1, 4] = 40.0
+    model.data[0, 2, 1, 4] = 160.0
+    model.data[0, 3, 1, 4] = 165.0
+    model.data[0, 4, 1, 4] = 170.0
+    model.data[0, 5, 1, 4] = 175.0
+    model.data[0, 6, 1, 4] = 180.0
+    model.data[0, 7, 1, 4] = 185.0
+    # ... and set 2 of the 4 neighbors to SAT, and adjust their ramps
+    model.groupdq[0, 2:, 0, 4] = SATURATED
+    model.groupdq[0, 2:, 1, 3] = SATURATED
+    model.data[0, 2:, 0, 4] = SAT_SCI
+    model.data[0, 2:, 1, 3] = SAT_SCI
+
+    # CR (C): group 2, on edge
+    model.data[0, 0, 4, 0] = 20.0
+    model.data[0, 1, 4, 0] = 35.0
+    model.data[0, 2, 4, 0] = 260.0
+    model.data[0, 3, 4, 0] = 275.0
+    model.data[0, 4, 4, 0] = 295.0
+    model.data[0, 5, 4, 0] = 310.0
+    model.data[0, 6, 4, 0] = 325.0
+    model.data[0, 7, 4, 0] = 340.0
+    # ... and set 1 of the 3 neighbors to SAT, and adjust its ramp
+    model.groupdq[0, 2:, 3, 0] = SATURATED
+    model.data[0, 2:, 3, 0] = SAT_SCI
+
+    # CR (D): group 2, not on edge
+    model.data[0, 0, 4, 5] = 60.0
+    model.data[0, 1, 4, 5] = 75.0
+    model.data[0, 2, 4, 5] = 160.0
+    model.data[0, 3, 4, 5] = 175.0
+    model.data[0, 4, 4, 5] = 195.0
+    model.data[0, 5, 4, 5] = 210.0
+    model.data[0, 6, 4, 5] = 225.0
+    model.data[0, 7, 4, 5] = 240.0
+    # ... and set 2 of the 4 neighbors to SAT, and adjust their ramps
+    model.groupdq[0, 2:, 4, 4] = SATURATED
+    model.groupdq[0, 2:, 4, 6] = SATURATED
+    model.data[0, 2:, 4, 4] = SAT_SCI
+    model.data[0, 2:, 4, 6] = SAT_SCI
+
+    # CR (E): group 4, not on edge
+    model.data[0, 0, 2, 5] = 20.0
+    model.data[0, 1, 2, 5] = 25.0
+    model.data[0, 2, 2, 5] = 31.0
+    model.data[0, 3, 2, 5] = 36.0
+    model.data[0, 4, 2, 5] = 190.0
+    model.data[0, 5, 2, 5] = 196.0
+    model.data[0, 6, 2, 5] = 201.0
+    model.data[0, 7, 2, 5] = 207.0
+    # ... and set 2 of the 4 neighbors to SAT, and adjust their ramps
+    model.groupdq[0, 4:, 1, 5] = SATURATED
+    model.groupdq[0, 4:, 3, 5] = SATURATED
+    model.data[0, 4:, 1, 5] = SAT_SCI
+    model.data[0, 4:, 3, 5] = SAT_SCI
+
+    # CR (F): group 4, on edge
+    model.data[0, 0, 5, 2] = 50.0
+    model.data[0, 1, 5, 2] = 55.0
+    model.data[0, 2, 5, 2] = 61.0
+    model.data[0, 3, 5, 2] = 66.0
+    model.data[0, 4, 5, 2] = 290.0
+    model.data[0, 5, 5, 2] = 296.0
+    model.data[0, 6, 5, 2] = 301.0
+    model.data[0, 7, 5, 2] = 307.0
+    # ... and set 1 of the 3 neighbors to SAT, and adjust its ramp
+    model.groupdq[0, 4:, 5, 1] = SATURATED
+    model.data[0, 4:, 5, 1] = SAT_SCI
+
+    out_model = run_detect_jumps(model, gain, rnoise, 4.0, 5.0, 6.0, 'none', 200, 4, True)
+    dq_out = out_model.groupdq
+
+    # Do assertions for each cosmic ray and its neighbors
+    # CR (A):
+    # Check the CR-impacted pixel and non-SAT neighbor
+    assert dq_out[0, 2, 0, 0] == JUMP_DET
+    assert dq_out[0, 2, 1, 0] == JUMP_DET
+    # Check the SAT neighbor
+    assert dq_out[0, 2, 0, 1] == SATURATED
+
+    # CR (B):
+    # Check the CR-impacted pixel and 2 non-SAT neighbors
+    assert dq_out[0, 2, 1, 4] == JUMP_DET
+    assert dq_out[0, 2, 1, 5] == JUMP_DET
+    assert dq_out[0, 2, 2, 4] == JUMP_DET
+    # Check the 2 SAT neighbors
+    assert dq_out[0, 2, 0, 4] == SATURATED
+    assert dq_out[0, 2, 1, 3] == SATURATED
+
+    # CR (C):
+    # Check the CR-impacted pixel and 2 non-SAT neighbors
+    assert dq_out[0, 2, 4, 0] == JUMP_DET
+    assert dq_out[0, 2, 4, 1] == JUMP_DET
+    assert dq_out[0, 2, 5, 0] == JUMP_DET
+    # Check the SAT neighbor
+    assert dq_out[0, 2, 3, 0] == SATURATED
+
+    # CR (D):
+    # Check the CR-impacted pixel and 2 non-SAT neighbors
+    assert dq_out[0, 2, 4, 5] == JUMP_DET
+    assert dq_out[0, 2, 3, 5] == JUMP_DET
+    assert dq_out[0, 2, 5, 5] == JUMP_DET
+    # Check the 2 SAT neighbors
+    assert dq_out[0, 2, 4, 4] == SATURATED
+    assert dq_out[0, 2, 4, 6] == SATURATED
+
+    # CR (E):
+    # Check the CR-impacted pixel and 2 non-SAT neighbors
+    assert dq_out[0, 4, 2, 5] == JUMP_DET
+    assert dq_out[0, 4, 2, 4] == JUMP_DET
+    assert dq_out[0, 4, 2, 6] == JUMP_DET
+    # Check the 2 SAT neighbors
+    assert dq_out[0, 4, 1, 5] == SATURATED
+    assert dq_out[0, 4, 3, 5] == SATURATED
+
+    # CR (F):
+    # Check the CR-impacted pixel and 2 non-SAT neighbors
+    assert dq_out[0, 4, 5, 2] == JUMP_DET
+    assert dq_out[0, 4, 4, 2] == JUMP_DET
+    assert dq_out[0, 4, 5, 3] == JUMP_DET
+    # Check the 1 SAT neighbor
+    assert dq_out[0, 4, 5, 1] == SATURATED
+
+
 @pytest.fixture
 def setup_inputs():
     def _setup(ngroups=10, readnoise=10, nints=1, nrows=102, ncols=103,
