@@ -9,17 +9,18 @@ from tempfile import TemporaryDirectory
 import warnings
 
 import pytest
+pytest.importorskip('pysiaf')
 
-from astropy.io import fits
-from astropy.time import Time
+from astropy.io import fits  # noqa: E402
+from astropy.time import Time  # noqa: E402
 
-from jwst import datamodels
-from jwst.lib import engdb_mast
-from jwst.lib import engdb_tools
-from jwst.lib import set_telescope_pointing as stp
-from jwst.lib import siafdb
-from jwst.lib.tests.engdb_mock import EngDB_Mocker
-from jwst.tests.helpers import word_precision_check
+from jwst import datamodels  # noqa: E402
+from jwst.lib import engdb_mast  # noqa: E402
+from jwst.lib import engdb_tools  # noqa: E402
+from jwst.lib import set_telescope_pointing as stp  # noqa: E402
+from jwst.lib import siafdb  # noqa: E402
+from jwst.lib.tests.engdb_mock import EngDB_Mocker  # noqa: E402
+from jwst.tests.helpers import word_precision_check  # noqa: E402
 
 # Ensure that `set_telescope_pointing` logs.
 stp.logger.setLevel(logging.DEBUG)
@@ -39,7 +40,7 @@ TARG_DEC = -87.0
 DATA_PATH = Path(__file__).parent / 'data'
 db_ngas_path = DATA_PATH / 'engdb_ngas'
 db_jw703_path = DATA_PATH / 'engdb_jw00703'
-siaf_path = DATA_PATH / 'siaf.db'
+siaf_path = DATA_PATH / 'xml_data_siafxml' / 'SIAFXML'
 
 # Some expected values
 Q_EXPECTED = np.asarray(
@@ -160,7 +161,7 @@ def test_override_calc_wcs():
 
     assert vinfo_new != vinfo
     assert all(np.isclose(vinfo_new,
-                          stp.WCSRef(ra=32.50407337171124, dec=17.161233048951043, pa=352.28553015159287)))
+                          stp.WCSRef(ra=32.504066294908846, dec=17.16116653015435, pa=352.2757851954435)))
 
 
 @pytest.mark.parametrize(
@@ -296,7 +297,11 @@ def test_pointing_averaging(eng_db_jw703):
 
 def test_get_pointing_fail():
     with pytest.raises(Exception):
-        q, j2fgs_matrix, fmscorr, obstime, gs_commanded = stp.get_pointing(47892.0, 48256.0)
+        (q,
+         j2fgs_matrix,
+         fmscorr,
+         obstime,
+         gs_commanded) = stp.get_pointing(47892.0, 48256.0)
 
 
 def test_get_pointing(eng_db_ngas):
@@ -482,12 +487,13 @@ def test_add_wcs_method_full_nosiafdb(eng_db_ngas, data_file, tmp_path):
             assert word_precision_check(model.meta.wcsinfo.s_region, expected.meta.wcsinfo.s_region)
 
 
-def test_add_wcs_method_full_siafdb(eng_db_ngas, data_file, tmp_path):
+@pytest.mark.parametrize('source, prd', [(siaf_path, None), (None, 'prdopssoc-053')])
+def test_add_wcs_method_full_siafdb(eng_db_ngas, data_file, tmp_path, source, prd):
     """Test using the database and a specified siaf db"""
     expected_name = 'add_wcs_method_full_siafdb.fits'
 
     # Calculate
-    stp.add_wcs(data_file, siaf_path=siaf_path, method=stp.Methods.OPS_TR_202111, engdb_url='http://localhost')
+    stp.add_wcs(data_file, siaf_path=siaf_path, prd=prd, method=stp.Methods.OPS_TR_202111, engdb_url='http://localhost')
 
     # Test
     with datamodels.Level1bModel(data_file) as model:
@@ -523,8 +529,8 @@ def test_default_siaf_values(eng_db_ngas, data_file_nosiaf):
         stp.update_wcs(model, siaf_path=siaf_path, allow_default=False, engdb_url='http://localhost')
         assert model.meta.wcsinfo.crpix1 == 24.5
         assert model.meta.wcsinfo.crpix2 == 24.5
-        assert model.meta.wcsinfo.cdelt1 == 3.067124166666667e-05
-        assert model.meta.wcsinfo.cdelt2 == 3.090061944444444e-05
+        assert model.meta.wcsinfo.cdelt1 == 3.0693922222222226e-05
+        assert model.meta.wcsinfo.cdelt2 == 3.092664722222222e-05
 
 
 def test_tsgrism_siaf_values(eng_db_ngas, data_file_nosiaf):
@@ -539,7 +545,7 @@ def test_tsgrism_siaf_values(eng_db_ngas, data_file_nosiaf):
         model.meta.exposure.type = "NRC_TSGRISM"
         model.meta.visit.tsovisit = True
         stp.update_wcs(model, siaf_path=siaf_path, engdb_url='http://localhost')
-        assert model.meta.wcsinfo.siaf_xref_sci == 952
+        assert model.meta.wcsinfo.siaf_xref_sci == 858.0
         assert model.meta.wcsinfo.siaf_yref_sci == 35
 
 
@@ -639,10 +645,7 @@ def calc_coarse_202111_fgsid(request, tmp_path_factory):
     # Save transforms for later examination
     transforms.write_to_asdf(tmp_path_factory.mktemp('transforms') / f'tforms_{t_pars.method}{truth_ext}.asdf')
 
-    try:
-        return transforms, t_pars, truth_ext, fgs_expected
-    finally:
-        t_pars.siaf_db.close()
+    return transforms, t_pars, truth_ext, fgs_expected
 
 
 @pytest.fixture(scope='module',
@@ -661,10 +664,7 @@ def calc_transforms(request, tmp_path_factory):
     # Save transforms for later examination
     transforms.write_to_asdf(tmp_path_factory.mktemp('transforms') / f'tforms_{request.param}.asdf')
 
-    try:
-        return transforms, t_pars
-    finally:
-        t_pars.siaf_db.close()
+    return transforms, t_pars
 
 
 @pytest.fixture
