@@ -20,6 +20,11 @@ from . import blender
 # with this code
 __rules_version__ = 2.1
 
+__all__ = ['find_keywords_in_section', 'first', 'float_one', 'int_one',
+           'interpret_attr_line', 'interpret_entry', 'last', 'maxdate',
+           'maxdatetime', 'maxtime', 'mindate', 'mindatetime', 'mintime',
+           'multi', 'multi1', 'zero', 'KeywordRules', 'KwRule']
+
 
 # Custom blending functions
 def multi(vals):
@@ -510,7 +515,7 @@ def find_keywords_in_section(hdr, title):
     The list will be derived from the section
         with the specified section title identified in the hdr.
     """
-    # Indentify card indices of start and end of specified section
+    # Identify card indices of start and end of specified section
     sect_start = None
     sect_end = None
     for i, kw in enumerate(hdr.cards):
