@@ -10,8 +10,10 @@ from ..outlier_detection import outlier_detection_step
 from ..tso_photometry import tso_photometry_step
 from ..extract_1d import extract_1d_step
 from ..white_light import white_light_step
+from ..photom import photom_step
 
 from ..lib.pipe_utils import is_tso
+from astropy.io.fits import FITS_rec
 
 __all__ = ['Tso3Pipeline']
 
@@ -26,6 +28,7 @@ class Tso3Pipeline(Pipeline):
         * outlier_detection
         * tso_photometry
         * extract_1d
+        * photom
         * white_light
     """
 
@@ -40,6 +43,7 @@ class Tso3Pipeline(Pipeline):
                  outlier_detection_step.OutlierDetectionStep,
                  'tso_photometry': tso_photometry_step.TSOPhotometryStep,
                  'extract_1d': extract_1d_step.Extract1dStep,
+                 'photom': photom_step.PhotomStep,
                  'white_light': white_light_step.WhiteLightStep
                  }
     reference_file_types = ['gain', 'readnoise']
@@ -148,6 +152,8 @@ class Tso3Pipeline(Pipeline):
             # define output for x1d (level 3) products
             x1d_result = datamodels.MultiSpecModel()
             x1d_result.update(input_models[0], only="PRIMARY")
+            x1d_result.int_times = FITS_rec.from_columns(input_models[0].int_times.columns,
+                                                         nrows=input_models[0].meta.exposure.nints)
 
             # Remove source_type from the output model, if it exists, to prevent
             # the creation of an empty SCI extension just for that keyword.
@@ -159,11 +165,22 @@ class Tso3Pipeline(Pipeline):
                 # extract 1D
                 self.log.info("Extracting 1-D spectra ...")
                 result = self.extract_1d(cube)
-                x1d_result.spec.extend(result.spec)
+                for row in cube.int_times:
+                    # Subtract one to assign 1-indexed int_nums to int_times array locations
+                    x1d_result.int_times[row[0] - 1] = row
 
-                # perform white-light photometry on 1d extracted data
-                self.log.info("Performing white-light photometry ...")
-                phot_result_list.append(self.white_light(result))
+                # SOSS F277W may return None - don't bother with that
+                if result is not None:
+                    if input_exptype == 'NIS_SOSS':
+                        # SOSS data have yet to be photometrically calibrated
+                        # Calibrate 1D spectra here.
+                        result = self.photom(result)
+
+                    x1d_result.spec.extend(result.spec)
+
+                    # perform white-light photometry on 1d extracted data
+                    self.log.info("Performing white-light photometry ...")
+                    phot_result_list.append(self.white_light(result))
 
             # Update some metadata from the association
             x1d_result.meta.asn.pool_name = input_models.meta.asn_table.asn_pool
@@ -176,7 +193,8 @@ class Tso3Pipeline(Pipeline):
         input_models.close()
 
         # Check for all null photometry results before saving
-        if phot_result_list.count(None) == len(phot_result_list):
+        all_none = np.all([(x is None) for x in phot_result_list])
+        if all_none:
             self.log.warning("Could not create a photometric catalog; all results are null")
         else:
             # Otherwise, save results to a photometry catalog file
