@@ -2,8 +2,7 @@ import os
 import pytest
 from astropy.io.fits.diff import FITSDiff
 
-from jwst.pipeline.collect_pipeline_cfgs import collect_pipeline_cfgs
-from jwst.stpipe import Step
+from jwst.master_background import MasterBackgroundStep
 
 
 @pytest.fixture(scope="module")
@@ -11,13 +10,9 @@ def run_pipeline(jail, rtdata_module):
 
     rtdata = rtdata_module
 
-    collect_pipeline_cfgs("config")
-
     rtdata.get_asn("miri/mrs/miri_mrs_mbkg_0304_spec3_asn.json")
 
-    args = ["config/master_background.cfg", rtdata.input,
-            "--save_results=True"]
-    Step.from_cmdline(args)
+    MasterBackgroundStep.call(rtdata.input, save_results=True, suffix='master_background')
 
     return rtdata
 
