@@ -6,6 +6,10 @@ from jwst.lib import engdb_tools
 from jwst.lib.set_telescope_pointing import add_wcs
 from jwst.lib.tests.engdb_mock import EngDB_Mocker
 
+# Get the mock databases
+DATA_PATH = Path(__file__).parents[1] / 'lib' / 'tests' / 'data'
+ENGDB_PATH = DATA_PATH / 'engdb'
+
 
 @pytest.mark.bigdata
 def test_miri_setpointing(_jail, rtdata, engdb, fitsdiff_default_kwargs):
@@ -13,9 +17,6 @@ def test_miri_setpointing(_jail, rtdata, engdb, fitsdiff_default_kwargs):
     Regression test of the set_telescope_pointing script on a level-1b MIRI image.
     """
 
-    # Get SIAF PRD database file
-    siaf_path = rtdata.get_data("common/prd.db")
-
     # Get the input level-1b file
     rtdata.get_data("miri/image/jw80600010001_02101_00001_mirimage_uncal.fits")
 
@@ -23,7 +24,7 @@ def test_miri_setpointing(_jail, rtdata, engdb, fitsdiff_default_kwargs):
     rtdata.output = rtdata.input
 
     # Call the WCS routine, using the ENGDB_Service
-    add_wcs(rtdata.input, allow_default=True, engdb_url='http://localhost', siaf_path=siaf_path)
+    add_wcs(rtdata.input, allow_default=True, engdb_url='http://localhost', prd='PRDOPSSOC-055')
 
     # Compare the results
     rtdata.get_truth("truth/test_miri_setpointing/jw80600010001_02101_00001_mirimage_uncal.fits")
@@ -38,7 +39,6 @@ def test_miri_setpointing(_jail, rtdata, engdb, fitsdiff_default_kwargs):
 @pytest.fixture
 def engdb():
     """Setup the mock engineering database"""
-    db_path = Path(__file__).parents[1] / 'lib' / 'tests' / 'data' / 'engdb'
-    with EngDB_Mocker(db_path=db_path):
+    with EngDB_Mocker(db_path=ENGDB_PATH):
         engdb = engdb_tools.ENGDB_Service(base_url='http://localhost')
         yield engdb
