@@ -7,12 +7,16 @@ JWST pipeline step for sky matching.
 
 """
 
-import collections
-import numpy as np
+from copy import deepcopy
 import logging
 
+import numpy as np
+
 from ..stpipe import Step
 from .. import datamodels
+from ..datamodels.dqflags import pixel
+from ..datamodels.util import open as datamodel_open
+
 
 from astropy.nddata.bitmask import (
     bitfield_to_boolean_mask,
@@ -24,6 +28,7 @@ from .skymatch import match
 from .skyimage import SkyImage, SkyGroup
 from .skystatistics import SkyStats
 
+
 __all__ = ['SkyMatchStep']
 
 
@@ -32,6 +37,8 @@ class SkyMatchStep(Step):
     SkyMatchStep: Subtraction or equalization of sky background in science images.
     """
 
+    class_alias = "skymatch"
+
     spec = """
         # General sky matching parameters:
         skymethod = option('local', 'global', 'match', 'global+match', default='match') # sky computation method
@@ -43,7 +50,7 @@ class SkyMatchStep(Step):
 
         # Sky statistics parameters:
         skystat = option('median', 'midpt', 'mean', 'mode', default='mode') # sky statistics
-        dqbits = string(default=0) # "good" DQ bits
+        dqbits = string(default='~DO_NOT_USE+NON_SCIENCE') # "good" DQ bits
         lower = float(default=None) # Lower limit of "good" pixel values
         upper = float(default=None) # Upper limit of "good" pixel values
         nclip = integer(min=0, default=5) # number of sky clipping iterations
@@ -56,9 +63,18 @@ class SkyMatchStep(Step):
 
     def process(self, input):
         self.log.setLevel(logging.DEBUG)
-        img = datamodels.ModelContainer(input)
+        # for now turn off memory optimization until we have better machinery
+        # to handle outputs in a consistent way.
+        self._is_asn = False
+        # self._is_asn = datamodels.util.is_association(input) or isinstance(input, str)
 
-        self._dqbits = interpret_bit_flags(self.dqbits)
+        img = datamodels.ModelContainer(
+            input,
+            save_open=not self._is_asn,
+            return_open=not self._is_asn
+        )
+
+        self._dqbits = interpret_bit_flags(self.dqbits, flag_name_map=pixel)
 
         # set sky statistics:
         self._skystat = SkyStats(
@@ -99,44 +115,24 @@ class SkyMatchStep(Step):
         # set sky background value in each image's meta:
         for im in images:
             if isinstance(im, SkyImage):
-                if im.is_sky_valid:
-                    self._set_sky_background(im.meta['image_model'], im.sky)
-                    im.meta['image_model'].meta.cal_step.skymatch = "COMPLETE"
-                else:
-                    im.meta['image_model'].meta.cal_step.skymatch = "SKIPPED"
+                self._set_sky_background(
+                    im,
+                    "COMPLETE" if im.is_sky_valid else "SKIPPED"
+                )
             else:
                 for gim in im:
-                    if gim.is_sky_valid:
-                        self._set_sky_background(
-                            gim.meta['image_model'],
-                            gim.sky
-                        )
-                        gim.meta['image_model'].meta.cal_step.skymatch = "COMPLETE"
-                    else:
-                        gim.meta['image_model'].meta.cal_step.skymatch = "SKIPPED"
+                    self._set_sky_background(
+                        gim,
+                        "COMPLETE" if gim.is_sky_valid else "SKIPPED"
+                    )
 
-        return img
-
-    # DEBUG: remove _group_images_by_id() once we are past
-    # debugging stage.
-    def _group_images_by_id(self, image_list):
-
-        # group images by their "group id":
-        imdict = collections.OrderedDict()
-
-        for im in image_list:
-            groupid = im.meta.observation.observation_label
-
-            if groupid in imdict:
-                imdict[groupid].append(im)
-            else:
-                imdict[groupid] = [im]
-
-        return imdict.values()
+        return input if self._is_asn else img
 
     def _imodel2skyim(self, image_model):
+        input_image_model = image_model
+        if self._is_asn:
+            image_model = datamodel_open(image_model)
 
-        # create
         if self._dqbits is None:
             dqmask = np.isfinite(image_model.data).astype(dtype=np.uint8)
         else:
@@ -151,6 +147,9 @@ class SkyMatchStep(Step):
         # if 'subtract' mode has changed compared to the previous pass:
         if image_model.meta.background.subtracted is None:
             if image_model.meta.background.level is not None:
+                if self._is_asn:
+                    image_model.close()
+
                 # report inconsistency:
                 raise ValueError("Background level was set but the "
                                  "'subtracted' property is undefined (None).")
@@ -164,6 +163,9 @@ class SkyMatchStep(Step):
                 # at this moment I think it is saver to quit and...
                 #
                 # report inconsistency:
+                if self._is_asn:
+                    image_model.close()
+
                 raise ValueError("Background level was subtracted but the "
                                  "'level' property is undefined (None).")
 
@@ -171,29 +173,56 @@ class SkyMatchStep(Step):
                 # cannot run 'skymatch' step on already "skymatched" images
                 # when 'subtract' spec is inconsistent with
                 # meta.background.subtracted:
+                if self._is_asn:
+                    image_model.close()
+
                 raise ValueError("'subtract' step's specification is "
                                  "inconsistent with background info already "
                                  "present in image '{:s}' meta."
                                  .format(image_model.meta.filename))
 
+        wcs = deepcopy(image_model.meta.wcs)
+
         sky_im = SkyImage(
             image=image_model.data,
-            wcs_fwd=image_model.meta.wcs.__call__,
-            wcs_inv=image_model.meta.wcs.invert,
+            wcs_fwd=wcs.__call__,
+            wcs_inv=wcs.invert,
             pix_area=1.0,  # TODO: pixel area
             convf=1.0,  # TODO: conv. factor to brightness
             mask=dqmask,
             id=image_model.meta.filename,  # file name?
             skystat=self._skystat,
             stepsize=self.stepsize,
-            meta={'image_model': image_model}
+            reduce_memory_usage=self._is_asn,
+            meta={'image_model': input_image_model}
         )
 
+        if self._is_asn:
+            image_model.close()
+
         if self.subtract:
             sky_im.sky = level
 
         return sky_im
 
-    def _set_sky_background(self, image, sky):
-        image.meta.background.level = sky
-        image.meta.background.subtracted = self.subtract
+    def _set_sky_background(self, sky_image, step_status):
+        image = sky_image.meta['image_model']
+        sky = sky_image.sky
+
+        if self._is_asn:
+            dm = datamodel_open(image)
+        else:
+            dm = image
+
+        if step_status == "COMPLETE":
+            dm.meta.background.method = str(self.skymethod)
+            dm.meta.background.level = sky
+            dm.meta.background.subtracted = self.subtract
+            if self.subtract:
+                dm.data[...] = sky_image.image[...]
+
+        dm.meta.cal_step.skymatch = step_status
+
+        if self._is_asn:
+            dm.save(image)
+            dm.close()
