@@ -20,7 +20,7 @@ from astropy.modeling.models import math as astmath
 from astropy.utils import isiterable
 
 
-__all__ = ['Gwa2Slit','Slit2Msa', 'Logical', 'NirissSOSSModel', 'Slit',
+__all__ = ['Gwa2Slit', 'Slit2Msa', 'Logical', 'NirissSOSSModel', 'Slit',
            'NIRCAMForwardRowGrismDispersion', 'NIRCAMForwardColumnGrismDispersion',
            'NIRCAMBackwardGrismDispersion', 'MIRI_AB2Slice', 'GrismObject',
            'NIRISSForwardRowGrismDispersion', 'NIRISSForwardColumnGrismDispersion',
@@ -56,6 +56,7 @@ class GrismObject(namedtuple('GrismObject', ("sid",
                                              "xcentroid",
                                              "ycentroid",
                                              "is_extended",
+                                             "isophotal_abmag",
                                              ), rename=False)):
     """ Grism Objects identified from a direct image catalog and segment map.
 
@@ -74,6 +75,10 @@ class GrismObject(namedtuple('GrismObject', ("sid",
         True if the order is only partially contained on the image
     waverange : list
         wavelength range for the order
+    is_extended : bool
+        True if marked as extended in the source catalog
+    isophotal_abmag : float
+        isophotal_abmag from the source catalog
     sky_centroid: `~astropy.coordinates.SkyCoord`
         ra and dec of the center of the object
     sky_bbox_ll : `~astropy.coordinates.SkyCoord`
@@ -114,7 +119,8 @@ class GrismObject(namedtuple('GrismObject', ("sid",
                 sky_bbox_ul=None,
                 xcentroid=None,
                 ycentroid=None,
-                is_extended=None):
+                is_extended=None,
+                isophotal_abmag=None):
 
         return super(GrismObject, cls).__new__(cls,
                                                sid=sid,
@@ -128,7 +134,8 @@ class GrismObject(namedtuple('GrismObject', ("sid",
                                                sky_bbox_ul=sky_bbox_ul,
                                                xcentroid=xcentroid,
                                                ycentroid=ycentroid,
-                                               is_extended=is_extended)
+                                               is_extended=is_extended,
+                                               isophotal_abmag=isophotal_abmag)
 
     def __str__(self):
         """Return a pretty print for the object information."""
@@ -143,6 +150,8 @@ class GrismObject(namedtuple('GrismObject', ("sid",
                 "ycentroid: {8}\n"
                 "partial_order: {9}\n"
                 "waverange: {10}\n"
+                "is_extended: {11}\n"
+                "isophotal_abmag: {12}\n"
                 .format(self.sid,
                         str(self.order_bounding),
                         str(self.sky_centroid),
@@ -153,7 +162,9 @@ class GrismObject(namedtuple('GrismObject', ("sid",
                         self.xcentroid,
                         self.ycentroid,
                         str(self.partial_order),
-                        str(self.waverange)))
+                        str(self.waverange),
+                        str(self.is_extended),
+                        str(self.isophotal_abmag)))
 
 
 class MIRI_AB2Slice(Model):
@@ -877,11 +888,11 @@ class NIRISSBackwardGrismDispersion(Model):
 
         Parameters
         ----------
-        wavelength : int,float
+        wavelength : float
             Input wavelength you want to know about, will be converted to float
-        x :  int,float
+        x : float
             Input x location
-        y :  int,float
+        y : float
             Input y location
         wavelength : float
             Wavelength to disperse
@@ -913,15 +924,15 @@ class NIRISSBackwardGrismDispersion(Model):
         xmodel = self.xmodels[iorder]
         ymodel = self.ymodels[iorder]
 
-        dx = xmodel[0](x, y) + t * xmodel[1](x, y)
-        dy = ymodel[0](x, y) + t * ymodel[1](x, y)
+        dx = xmodel[0](x, y) + t * xmodel[1](x, y) + t**2 * xmodel[2](x, y)
+        dy = ymodel[0](x, y) + t * ymodel[1](x, y) + t**2 * ymodel[2](x, y)
 
         # rotate by theta
         if self.theta != 0.0:
             rotate = Rotation2D(self.theta)
             dx, dy = rotate(dx, dy)
 
-        return (x + dx, y + dy, x, y, order)
+        return x + dx, y + dy, x, y, order
 
 
 class NIRISSForwardRowGrismDispersion(Model):
@@ -1025,8 +1036,8 @@ class NIRISSForwardRowGrismDispersion(Model):
         ymodel = self.ymodels[iorder]
         lmodel = self.lmodels[iorder]
 
-        dx = xmodel[0](x00, y00) + t * xmodel[1](x00, y00)
-        dy = ymodel[0](x00, y00) + t * ymodel[1](x00, y00)
+        dx = xmodel[0](x00, y00) + t * xmodel[1](x00, y00) + t**2 * xmodel[2](x00, y00)
+        dy = ymodel[0](x00, y00) + t * ymodel[1](x00, y00) + t**2 * ymodel[2](x00, y00)
 
         if self.theta != 0.0:
             rotate = Rotation2D(self.theta)
@@ -1038,6 +1049,7 @@ class NIRISSForwardRowGrismDispersion(Model):
         dxr = astmath.SubtractUfunc()
         wavelength = dxr | tab | lmodel
         model = Mapping((2, 3, 0, 2, 4)) | Const1D(x00) & Const1D(y00) & wavelength & Const1D(order)
+        # returns x0, y0, lam, order
         return model(x, y, x0, y0, order)
 
 
@@ -1136,15 +1148,14 @@ class NIRISSForwardColumnGrismDispersion(Model):
         xmodel = self.xmodels[iorder]
         ymodel = self.ymodels[iorder]
         lmodel = self.lmodels[iorder]
-        dx = xmodel[0](x00, y00) + t * xmodel[1](x00, y00)
-        dy = ymodel[0](x00, y00) + t * ymodel[1](x00, y00)
+        dx = xmodel[0](x00, y00) + t * xmodel[1](x00, y00) + t**2 * xmodel[2](x00, y00)
+        dy = ymodel[0](x00, y00) + t * ymodel[1](x00, y00) + t**2 * ymodel[2](x00, y00)
 
         if self.theta != 0.0:
             rotate = Rotation2D(self.theta)
             dx, dy = rotate(dx, dy)
         so = np.argsort(dy)
         tab = Tabular1D(dy[so], t[so], bounds_error=False, fill_value=None)
-
         dyr = astmath.SubtractUfunc()
         wavelength = dyr | tab | lmodel
         model = Mapping((2, 3, 1, 3, 4)) | Const1D(x00) & Const1D(y00) & wavelength & Const1D(order)
