@@ -9,7 +9,7 @@ from jwst.tweakreg import TweakRegStep
 
 
 @pytest.mark.parametrize("offset, is_good", [(1 / 3600, True), (11 / 3600, False)])
-def test_fit_quality_is_good(offset, is_good):
+def test_is_wcs_correction_small(offset, is_good):
     path = os.path.join(os.path.dirname(__file__), "mosaic_long_i2d_gwcs.asdf")
     with asdf.open(path) as af:
         wcs = af.tree["wcs"]
@@ -22,4 +22,4 @@ def test_fit_quality_is_good(offset, is_good):
 
     step = TweakRegStep()
 
-    assert step.fit_quality_is_good(wcs, twcs) == is_good
+    assert step._is_wcs_correction_small(wcs, twcs) == is_good
