@@ -13,10 +13,12 @@ class WhiteLightStep(Step):
     multi-integration spectroscopic observation.
     """
 
+    class_alias = "white_light"
+
     spec = """
     min_wavelength     = float(default=None)      # Default wavelength minimum for integration
     max_wavelength     = float(default=None)      # Default wavelength maximum for integration
-    output_ext         = string(default='.ecsv')  # Default type of output
+    output_ext         = string(default='.ecsv')  # Output file type
     suffix             = string(default='whtlt')  # Default suffix for output files
     """
 
